@@ -21,9 +21,9 @@ from spider.utils.collision import BoxCollisionChecker
 from spider.constraints import CartConstriantChecker
 
 
-class LatticePlanner(BasicPlanner):
+class Bezier(BasicPlanner):
     def __init__(self, config=None):
-        super(LatticePlanner, self).__init__()
+        super(BasicPlanner, self).__init__()
 
         self.config = self.default_config()
         if not (config is None):
