@@ -1,5 +1,5 @@
 from spider.elements.trajectory import Trajectory, FrenetTrajectory
-from spider.elements.curves import ParametricCurve, Curve1d
+from spider.elements.curves import ParametricCurve, ExplicitCurve
 import numpy as np
 
 class LatLonCombiner:
@@ -8,9 +8,9 @@ class LatLonCombiner:
     PVD本质是路径和速度（标量速度）的分解
     换句话讲，分解为路径曲线的生成 和 速度曲线的生成
 
-    在frenet框架下，也应该是l(s) 和 v(t) ，然后一起生成轨迹, v(t) 决定了每一时刻的里程数， 去l(s)上面去找速度积分得到对应的里程数
+    在frenet框架下，也应该是l(s) 和 v(x) ，然后一起生成轨迹, v(x) 决定了每一时刻的里程数， 去l(s)上面去找速度积分得到对应的里程数
     里程是什么？里程是速度的积分，是曲线上长度的累积，不是s！s只是横轴！
-    然而这里的代码，是l(s) 和 s(t)， s(t)本质上不是严格的由速度导出的里程数。
+    然而这里的代码，是l(s) 和 s(x)， s(x)本质上不是严格的由速度导出的里程数。
     命名来讲，横纵向解耦更符合
     '''
     def __init__(self, steps, dt):
@@ -63,16 +63,23 @@ class PVDCombiner:
             # ss_abs = [s + ego_s0 for s in ss]  # 注意，加上ego_s0这一步非常重要,从相对变为绝对frenet坐标
             s0 = ss[0]
             for path_generator in path_generators:
+                # 可以把ss一起放进去，不用一个个扔进去
                 xys, dxys, ddxys, dddxys = [[path_generator(s-s0, order) for s in ss] for order in range(4)]
 
                 traj = Trajectory(self.steps, self.dt)
                 traj.t = ts
                 traj.x, traj.y = xys
-                traj.v = np.linalg.norm(dxys)
+                traj.v = np.linalg.norm(dxys, axis=1)
+                traj.heading = np.arctan2(dxys[:,1], dxys[:,0])
+                traj.a = np.linalg.norm(ddxys, axis=1)
 
-                traj.heading = np.arctan2()
-                traj.s, traj.s_dot, traj.s_2dot, traj.s_3dot = ss, dss, ddss, dddss
-                traj.l, traj.l_prime, traj.l_2prime, traj.l_3prime = ls, dls, ddls, dddls
+                traj.steer = []
+                traj.curvature = []
+                traj.centripetal_acceleration = []
+
+
+                # traj.s, traj.s_dot, traj.s_2dot, traj.s_3dot = ss, dss, ddss, dddss
+                # traj.l, traj.l_prime, traj.l_2prime, traj.l_3prime = ls, dls, ddls, dddls
                 candidate_trajectories.append(traj)
 
         return candidate_trajectories
